#ifndef COIN_XML_ATTRIBUTE_H
#define COIN_XML_ATTRIBUTE_H

/**************************************************************************\
 * Copyright (c) Kongsberg Oil & Gas Technologies AS
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 
 * Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\**************************************************************************/

#include <Inventor/C/XML/types.h>

/* ********************************************************************** */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

COIN_DLL_API cc_xml_attr * cc_xml_attr_new(void);
COIN_DLL_API cc_xml_attr * cc_xml_attr_new_from_data(const char * name, const char * value);
COIN_DLL_API cc_xml_attr * cc_xml_attr_clone(const cc_xml_attr * orig);
COIN_DLL_API void cc_xml_attr_delete_x(cc_xml_attr * attr);

COIN_DLL_API void cc_xml_attr_set_name_x(cc_xml_attr * attr, const char * name);
COIN_DLL_API const char * cc_xml_attr_get_name(const cc_xml_attr * attr);
COIN_DLL_API void cc_xml_attr_set_value_x(cc_xml_attr * attr, const char * value);
COIN_DLL_API const char * cc_xml_attr_get_value(const cc_xml_attr * attr);

/* TODO: type-specific/converting attribute accessors
COIN_DLL_API int cc_xml_attr_is_int32(const cc_xml_attr * attr);
COIN_DLL_API int32_t cc_xml_attr_get_int32(const cc_xml_attr * attr);
COIN_DLL_API void cc_xml_attr_set_int32_x(const cc_xml_attr * attr, int32_t intval);
*/

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

/* ********************************************************************** */

#endif /* !COIN_XML_ATTRIBUTE_H */
